pub struct Renderer { /* private fields */ }Implementations
Sourceimpl Renderer
impl Renderer
Sourcepub fn draw_table(&mut self, table: &Table, cur: &Cursor, anchor: &Cursor)
pub fn draw_table(&mut self, table: &Table, cur: &Cursor, anchor: &Cursor)
Draws the table to the screen, highlights the cell the cursor is located
Sourcepub fn draw_prompt(&mut self, prompt: PromptType, buffer: &String)
pub fn draw_prompt(&mut self, prompt: PromptType, buffer: &String)
Draws at bottom of screen, exits raw mode, waits for input
Sourcepub fn clear_prompt(&mut self)
pub fn clear_prompt(&mut self)
Draws at bottom of screen, exits raw mode, waits for input
pub fn clear_screen(&mut self)
pub fn draw_status(&mut self, mode: Mode)